import { AppRoles, User, UserRole } from './types';

export const transformAppRoles = (data: any): AppRoles => {
  const resolvedAdminRole = data.role_id === 1 ? UserRole.Admin : UserRole.User;

  return {
    name: data.name ?? '',
    role: resolvedAdminRole ?? UserRole.User,
  };
};

export const transformRequestAppRoles = (data: AppRoles): any => {
  const resolvedRequestRole = data.role === UserRole.Admin ? 1 : null;

  return {
    name: data.name ?? '',
    role_id: resolvedRequestRole,
  };
};

export const transformUser = (response: any): User => {
  return {
    id: response.id ?? '',
    app_roles: response.traits.app_roles ? response.traits.app_roles.map(transformAppRoles) : [],
    email: response.traits.email ?? '',
    name: response.traits.name ?? '',
    preferredUsername: response.preferredUsername ?? '',
    status: response.state ?? '',
  };
};

export const transformRequestUser = (data: Pick<User, 'app_roles' | 'name' | 'email'>) => {
  return {
    app_roles: data.app_roles.map(transformRequestAppRoles),
    email: data.email ?? '',
    name: data.name ?? '',
  };
};
